@@ -39,19 +39,6 @@ typedef enum {
 } RtpSessionMode;
 
 
-
-typedef enum {
-	RTP_SESSION_RECV_SYNC=1,	/* the rtp session is synchronising in the incoming stream */
-	RTP_SESSION_SEND_SYNC=1<<1, /* the rtp session is synchronising in the outgoing stream */
-	RTP_SESSION_SCHEDULED=1<<2, /* the rtp session has to be scheduled */
-	RTP_SESSION_BLOCKING_MODE=1<<3, /* in blocking mode */
-	RTP_SESSION_RECV_NOT_STARTED=1<<4,	/* the application has not started to try to recv */
-	RTP_SESSION_SEND_NOT_STARTED=1<<5,  /* the application has not started to send something */
-	RTP_SESSION_IN_SCHEDULER=1<<6,	/* the rtp session is in the scheduler list */
-	RTP_SESSION_USING_EXT_SOCKETS=1<<7 /* the session is using externaly supplied sockets */
-}RtpSessionFlags;
-
-
 typedef struct _JitterControl
 {
 	int jitt_comp;   /* the user jitt_comp in miliseconds*/
@@ -74,10 +61,26 @@ typedef struct _WaitPoint
 	uint32_t time;
 	bool_t wakeup;
 } WaitPoint;
+
+typedef struct _RtpTransport
+{
+  void *data;
+  ortp_socket_t (*t_getsocket)(struct _RtpTransport *t);
+#ifdef ORTP_INET6
+  int  (*t_sendto)(struct _RtpTransport *t, const  void *buf, size_t len, int flags, const struct sockaddr *to, socklen_t tolen);
+  int  (*t_recvfrom)(struct _RtpTransport *t, void *buf, size_t len, int flags, struct sockaddr *from, socklen_t *fromlen);
+#else
+  int  (*t_sendto)(struct _RtpTransport *t, const  void *buf, size_t len, int flags, const struct sockaddr *to, socklen_t tolen);
+  int  (*t_recvfrom)(struct _RtpTransport *t, void *buf, size_t len, int flags, struct sockaddr *from, socklen_t *fromlen);
+#endif
+}  RtpTransport;
+
+
 	
 typedef struct _RtpStream
 {
 	ortp_socket_t socket;
+        struct _RtpTransport *tr; 
 	int sockfamily;
 	int max_rq_size;
 	int time_jump;
@@ -126,6 +129,8 @@ typedef struct _RtcpStream
 {
 	ortp_socket_t socket;
 	int sockfamily;
+        struct _RtpTransport *tr; 
+
 	mblk_t *cached_mp;
 #ifdef ORTP_INET6
 	struct sockaddr_storage rem_addr;
@@ -143,13 +148,13 @@ struct _RtpSession
 {
 	RtpSession *next;	/* next RtpSession, when the session are enqueued by the scheduler */
 	int mask_pos;	/* the position in the scheduler mask of RtpSession : do not move this field: it is part of the ABI since the session_set macros use it*/
-	RtpProfile *profile;
-	WaitPoint recv_wp;
-	WaitPoint send_wp;
-	uint32_t send_ssrc;
-	uint32_t recv_ssrc;
-	int send_pt;/* sent payload type */
-	int recv_pt;/* recv payload type */
+        struct {
+	  RtpProfile *profile;
+	  int pt;
+	  int ssrc;
+	  WaitPoint wp;
+	  int telephone_events_pt;	/* the payload type used for telephony events */
+	} snd,rcv;
 	int hw_recv_pt; /* recv payload type before jitter buffer */
 	int recv_buf_size;
 	RtpSignalTable on_ssrc_changed;
@@ -174,12 +179,12 @@ struct _RtpSession
 	struct timeval last_recv_time; /* Time of receiving the RTP/RTCP packet. */
 
 	/* telephony events extension */
-	int telephone_events_pt;	/* the payload type used for telephony events */
 	mblk_t *current_tev;		/* the pending telephony events */
 	mblk_t *sd;
 	queue_t contributing_sources;
 	bool_t symmetric_rtp;
 	bool_t permissive; /*use the permissive algorithm*/
+	bool_t use_connect; /* use connect() on the socket */
 };
 	
 
@@ -200,8 +205,12 @@ void rtp_session_uninit(RtpSession *session);
 RtpSession *rtp_session_new(int mode);
 void rtp_session_set_scheduling_mode(RtpSession *session, int yesno);
 void rtp_session_set_blocking_mode(RtpSession *session, int yesno);
-void rtp_session_set_profile(RtpSession *session,RtpProfile *profile);
+void rtp_session_set_profile(RtpSession *session, RtpProfile *profile);
+void rtp_session_set_send_profile(RtpSession *session,RtpProfile *profile);
+void rtp_session_set_recv_profile(RtpSession *session,RtpProfile *profile);
 RtpProfile *rtp_session_get_profile(RtpSession *session);
+RtpProfile *rtp_session_get_send_profile(RtpSession *session);
+RtpProfile *rtp_session_get_recv_profile(RtpSession *session);
 int rtp_session_signal_connect(RtpSession *session,const char *signal_name, RtpCallback cb, unsigned long user_data);
 int rtp_session_signal_disconnect_by_callback(RtpSession *session,const char *signal_name, RtpCallback cb);
 void rtp_session_set_ssrc(RtpSession *session, uint32_t ssrc);
@@ -217,6 +226,7 @@ int rtp_session_set_remote_addr(RtpSession *session,const char *addr, int port);
 /* alternatively to the set_remote_addr() and set_local_addr(), an application can give
 a valid socket (potentially connect()ed )to be used by the RtpSession */
 void rtp_session_set_sockets(RtpSession *session, int rtpfd, int rtcpfd);
+void rtp_session_set_transports(RtpSession *session, RtpTransport *rtptr, RtpTransport *rtcptr);
 
 /*those methods are provided for people who wants to send non-RTP messages using the RTP/RTCP sockets */
 ortp_socket_t rtp_session_get_rtp_socket(const RtpSession *session);
@@ -245,7 +255,9 @@ int rtp_session_set_recv_payload_type(RtpSession *session, int pt);
 
 int rtp_session_set_payload_type(RtpSession *session, int pt);
 
-void rtp_session_set_symmetric_rtp (RtpSession * session, int yesno);
+void rtp_session_set_symmetric_rtp (RtpSession * session, bool_t yesno);
+
+void rtp_session_set_connected_mode(RtpSession *session, bool_t yesno);
 
 /*low level recv and send functions */
 mblk_t * rtp_session_recvm_with_ts (RtpSession * session, uint32_t user_ts);
@@ -272,6 +284,7 @@ uint32_t rtp_session_get_current_send_ts(RtpSession *session);
 uint32_t rtp_session_get_current_recv_ts(RtpSession *session);
 void rtp_session_flush_sockets(RtpSession *session);
 void rtp_session_release_sockets(RtpSession *session);
+void rtp_session_resync(RtpSession *session);
 void rtp_session_reset(RtpSession *session);
 void rtp_session_destroy(RtpSession *session);
 
