@@ -18,7 +18,7 @@
 */
 
 
-#ifdef WIN32
+#if defined(WIN32) || defined(_WIN32_WCE)
 #include "ortp-config-win32.h"
 #else
 #include "ortp-config.h"
@@ -45,6 +45,23 @@ static void init_random_number_generator(){
 	srandom(t.tv_usec+t.tv_sec);
 }
 
+
+#ifdef WIN32
+static bool_t win32_init_sockets(void){
+	WORD wVersionRequested;
+	WSADATA wsaData;
+	int i;
+	
+	wVersionRequested = MAKEWORD(1,1);
+	if( (i = WSAStartup(wVersionRequested,  &wsaData))!=0)
+	{
+		ortp_error("Unable to initialize windows socket api, reason: %d",i);
+		return FALSE;
+	}
+	return TRUE;
+}
+#endif
+
 /**
  *ortp_init:
  *
@@ -58,6 +75,10 @@ void ortp_init()
 	if (initialized) return;
 	initialized=TRUE;
 
+#ifdef WIN32
+	win32_init_sockets();
+#endif
+
 	av_profile_init(&av_profile);
 	ortp_global_stats_reset();
 	init_random_number_generator();
@@ -200,19 +221,20 @@ char *ortp_strdup_printf(const char *fmt,...){
 	return ret;
 }
 
-#ifdef _WIN32
+#if	defined(WIN32) || defined(_WIN32_WCE)
 #define ENDLINE "\r\n"
 #else
 #define ENDLINE "\n"
 #endif
 
-#if defined(WIN32)
-
+#if	defined(WIN32) || defined(_WIN32_WCE)
 void ortp_logv(int level, const char *fmt, va_list args)
 {
 	if (ortp_logv_out!=NULL && ortp_log_level_enabled(level))
 		ortp_logv_out(level,fmt,args);
+#if !defined(_WIN32_WCE)
 	if ((level)==ORTP_FATAL) abort();
+#endif
 }
 #endif
 
@@ -267,7 +289,6 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header)
 	      " number of times the application queried a packet that didn't exist=%lld \n"
 		" number of rtp packet lost=%lld\n"
 	      " number of rtp packets received too late=%lld\n"
-	      " number of rtp packets skipped=%lld\n"
 	      " number of bad formatted rtp packets=%lld\n"
 	      " number of packet discarded because of queue overflow=%lld\n",
 	      header,
@@ -279,7 +300,6 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header)
 	      (long long)stats->unavaillable,
 		(long long)stats->cum_packet_loss,
 	      (long long)stats->outoftime,
-	      (long long)stats->skipped,
 	      (long long)stats->bad,
 	      (long long)stats->discarded);
 #else
@@ -293,21 +313,19 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header)
 	      " number of times the application queried a packet that didn't exist=%I64d \n"
 		" number of rtp packet lost=%I64d\n"
 	      " number of rtp packets received too late=%I64d\n"
-	      " number of rtp packets skipped=%I64d\n"
 	      " number of bad formatted rtp packets=%I64d\n"
 	      " number of packet discarded because of queue overflow=%I64d\n",
 	      header,
-	      (long long)stats->packet_sent,
-	      (long long)stats->sent,
-	      (long long)stats->packet_recv,
-	      (long long)stats->hw_recv,
-	      (long long)stats->recv,
-	      (long long)stats->unavaillable,
-		(long long) stats->cum_packet_loss,
-	      (long long)stats->outoftime,
-	      (long long)stats->skipped,
-	      (long long)stats->bad,
-	      (long long)stats->discarded);
+	      (uint64_t)stats->packet_sent,
+	      (uint64_t)stats->sent,
+	      (uint64_t)stats->packet_recv,
+	      (uint64_t)stats->hw_recv,
+	      (uint64_t)stats->recv,
+	      (uint64_t)stats->unavaillable,
+		(uint64_t) stats->cum_packet_loss,
+	      (uint64_t)stats->outoftime,
+	      (uint64_t)stats->bad,
+	      (uint64_t)stats->discarded);
 #endif
 }
 
