@@ -1,5 +1,5 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc1889) stack.
+  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
   Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
 
   This library is free software; you can redistribute it and/or
@@ -19,6 +19,7 @@
 
 #include "ortp/ortp.h"
 #include "ortp/payloadtype.h"
+#include "utils.h"
 
 /**
  *rtp_profile_clear_all:
@@ -47,7 +48,7 @@
 /**
  *rtp_profile_set_payload:
  *@profile: an RTP profile (a #RtpProfile object)
- *@index:	the payload type number
+ *@idx:	the payload type number
  *@pt:		the payload type description (a #PayloadType object )
  *
  *	Assign payload type number @index to payload type desribed in @pt for the RTP profile
@@ -84,7 +85,7 @@ char *payload_type_get_rtpmap(PayloadType *pt)
 
 PayloadType *payload_type_new()
 {
-	PayloadType *newpayload=ortp_new0(PayloadType,1);
+	PayloadType *newpayload=(PayloadType *)ortp_new0(PayloadType,1);
 	newpayload->flags|=PAYLOAD_TYPE_ALLOCATED;
 	return newpayload;
 }
@@ -92,11 +93,15 @@ PayloadType *payload_type_new()
 
 PayloadType *payload_type_clone(PayloadType *payload)
 {
-	PayloadType *newpayload=ortp_new0(PayloadType,1);
+	PayloadType *newpayload=(PayloadType *)ortp_new0(PayloadType,1);
 	memcpy(newpayload,payload,sizeof(PayloadType));
 	newpayload->mime_type=ortp_strdup(payload->mime_type);
-	if (payload->recv_fmtp!=NULL) newpayload->recv_fmtp=ortp_strdup(payload->recv_fmtp);
-	if (payload->send_fmtp!=NULL) newpayload->send_fmtp=ortp_strdup(payload->send_fmtp);
+	if (payload->recv_fmtp!=NULL) {
+		newpayload->recv_fmtp=ortp_strdup(payload->recv_fmtp);
+	}
+	if (payload->send_fmtp!=NULL){
+		newpayload->send_fmtp=ortp_strdup(payload->send_fmtp);
+	}
 	newpayload->flags|=PAYLOAD_TYPE_ALLOCATED;
 	return newpayload;
 }
@@ -134,6 +139,25 @@ void payload_type_destroy(PayloadType *pt)
 	ortp_free(pt);
 }
 
+
+bool_t fmtp_get_value(const char *fmtp, const char *param_name, char *result, size_t result_len){
+	const char *pos=strstr(fmtp,param_name);
+	if (pos){
+		const char *equal=strchr(pos,'=');
+		if (equal){
+			int copied;
+			const char *end=strchr(equal+1,';');
+			if (end==NULL) end=fmtp+strlen(fmtp); /*assuming this is the last param */
+			copied=MIN(result_len-1,end-(equal+1));
+			strncpy(result,equal+1,copied);
+			result[copied]='\0';
+			return TRUE;
+		}
+	}
+	return FALSE;
+}
+
+
 int rtp_profile_get_payload_number_from_mime(RtpProfile *profile,const char *mime)
 {
 	PayloadType *pt;
@@ -226,17 +250,17 @@ int rtp_profile_move_payload(RtpProfile *prof,int oldpos,int newpos){
 
 RtpProfile * rtp_profile_new(const char *name)
 {
-	RtpProfile *prof=ortp_new0(RtpProfile,1);
+	RtpProfile *prof=(RtpProfile*)ortp_new0(RtpProfile,1);
 	rtp_profile_set_name(prof,name);
 	return prof;
 }
 
-void rtp_profile_set_payload(RtpProfile *prof, int index, PayloadType *pt){
-	if (index<0 || index>=RTP_PROFILE_MAX_PAYLOADS) {
-		ortp_error("Bad index %i",index);
+void rtp_profile_set_payload(RtpProfile *prof, int idx, PayloadType *pt){
+	if (idx<0 || idx>=RTP_PROFILE_MAX_PAYLOADS) {
+		ortp_error("Bad index %i",idx);
 		return;
 	}
-	prof->payload[index]=pt;
+	prof->payload[idx]=pt;
 }
 
 void rtp_profile_clear_all(RtpProfile *obj){
@@ -286,7 +310,10 @@ void rtp_profile_destroy(RtpProfile *prof)
 {
 	int i;
 	PayloadType *payload;
-	if (prof->name) ortp_free(prof->name);
+	if (prof->name) {
+		ortp_free(prof->name);
+		prof->name = NULL;
+	}
 	for (i=0;i<RTP_PROFILE_MAX_PAYLOADS;i++)
 	{
 		payload=rtp_profile_get_payload(prof,i);
